# rsmime

[![PyPI](https://img.shields.io/pypi/v/rsmime?color=gr)](https://pypi.org/project/rsmime/) [![Tests](https://github.com/tiwilliam/rsmime/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/tiwilliam/rsmime/actions/workflows/tests.yml)

Python package for signing and verifying S/MIME messages

[Documentation](https://tiwilliam.github.io/rsmime/)

## License

MIT

A short and simple permissive license with conditions only requiring preservation of copyright and license notices. Licensed works, modifications, and larger works may be distributed under different terms and without source code.
